@@ -298,33 +298,24 @@ def rjb_inner_loop(M, Repi, conf):
                 for i in range(nx):
                     xj = x[i] + Repi * np.cos(theta)
 
-                    xltz = xj < 0
-                    xgez_and_xlesw = (xj >= 0) & (xj <= SW)
-                    xgtsw = xj > SW
-                    c1x = xltz
-                    c2x = xgez_and_xlesw
-                    c3x = xgtsw
-                    c4x = xltz
-                    c5x = xgez_and_xlesw
-                    c6x = xgtsw
-                    c7x = xltz
-                    c8x = xgez_and_xlesw
-                    c9x = xgtsw
+                    c147x = xj < 0
+                    c258x = (xj >= 0) & (xj <= SW)
+                    c369x = xj > SW
                     for j in range(ny):
                         yi = y[j] + Repi * np.sin(theta)
 
                         cca = yi > length[ll]
                         ccb = (yi >= 0) & (yi <= length[ll])
                         ccc = yi < 0
-                        c1 = c1x & cca
-                        c2 = c2x & cca
-                        c3 = c3x & cca
-                        c4 = c4x & ccb
-                        c5 = c5x & ccb
-                        c6 = c6x & ccb
-                        c7 = c7x & ccc
-                        c8 = c8x & ccc
-                        c9 = c9x & ccc
+                        c1 = c147x & cca
+                        c2 = c258x & cca
+                        c3 = c369x & cca
+                        c4 = c147x & ccb
+                        c5 = c258x & ccb
+                        c6 = c369x & ccb
+                        c7 = c147x & ccc
+                        c8 = c258x & ccc
+                        c9 = c369x & ccc
                         # The original version below. The above two chunks
                         # are an optimization of the following:
                         # c1 = (xj <  0) &              (yi > L[l])
@@ -379,10 +370,10 @@ def rjb_inner_loop(M, Repi, conf):
             integrand_width2[w] = np.trapz(peps * integrand_length2, dx=d_eps)
     if nw == 1:
         Rjb_avg = integrand_width[0]
-        Rjb_var = integrand_width2[0] - Rjb_avg**2
+        Rjb_var = integrand_width2[0] - Rjb_avg ** 2
     else:
         Rjb_avg = np.trapz(peps * integrand_width, dx=d_eps)
-        Rjb_var = np.trapz(peps * integrand_width2, dx=d_eps) - Rjb_avg**2
+        Rjb_var = np.trapz(peps * integrand_width2, dx=d_eps) - Rjb_avg ** 2
 
     return Rjb_var, Rjb_avg
 
@@ -532,33 +523,25 @@ def rrup_inner_loop(M, Repi, conf):
                     for i in range(nx):
                         xj = x[i] + Repi * np.cos(theta)
 
-                        xltz = xj < 0
-                        xgez_and_xlesw = (xj >= 0) & (xj <= SW)
-                        xgtsw = xj > SW
-                        c1x = xltz
-                        c2x = xgez_and_xlesw
-                        c3x = xgtsw
-                        c4x = xltz
-                        c5x = xgez_and_xlesw
-                        c6x = xgtsw
-                        c7x = xltz
-                        c8x = xgez_and_xlesw
-                        c9x = xgtsw
+                        c147x = xj < 0
+                        c258x = (xj >= 0) & (xj <= SW)
+                        c369x = xj > SW
                         for j in range(ny):
                             yi = y[j] + Repi * np.sin(theta)
 
                             cca = yi > length[ll]
                             ccb = (yi >= 0) & (yi <= length[ll])
                             ccc = yi < 0
-                            c1 = c1x & cca
-                            c2 = c2x & cca
-                            c3 = c3x & cca
-                            c4 = c4x & ccb
-                            c5 = c5x & ccb
-                            c6 = c6x & ccb
-                            c7 = c7x & ccc
-                            c8 = c8x & ccc
-                            c9 = c9x & ccc
+                            c1 = c147x & cca
+                            c2 = c258x & cca
+                            c3 = c369x & cca
+                            c4 = c147x & ccb
+                            c5 = c258x & ccb
+                            c6 = c369x & ccb
+                            c7 = c147x & ccc
+                            c8 = c258x & ccc
+                            c9 = c369x & ccc
+
                             # The original version. The above two chunks should
                             # implement this
                             # c1 = (xj <  0) &              (yi > L[l])
@@ -598,7 +581,7 @@ def rrup_inner_loop(M, Repi, conf):
                             # Compute Rrup prime, then Rrup
                             # using Kaklamanos eqns
                             if dip[k] == np.pi / 2:
-                                Rrup = np.sqrt(Rjb**2 + Ztor[z] ** 2)
+                                Rrup = np.sqrt(Rjb ** 2 + Ztor[z] ** 2)
                             else:
                                 tmp = Ztor[z] * np.tan(dip[k])
                                 r1 = Rx < tmp
@@ -614,8 +597,8 @@ def rrup_inner_loop(M, Repi, conf):
                                     (Rx[r3] - width[w] * np.cos(dip[k])) ** 2
                                     + (Ztor[z] + width[w] * np.sin(dip[k])) ** 2
                                 )
+                                Rrup = np.sqrt(Rrupp ** 2 + Ry ** 2)
 
-                            Rrup = np.sqrt(Rrupp**2 + Ry**2)
                             Rrup2 = Rrup * Rrup
 
                             integrand_y[j] = one_over_2pi * np.trapz(Rrup, dx=dt)
@@ -657,10 +640,10 @@ def rrup_inner_loop(M, Repi, conf):
             integrand_width2[w] = np.trapz(peps * integrand_length2, dx=d_eps)
     if nw == 1:
         Rrup_avg = integrand_width[0]
-        Rrup_var = integrand_width2[0] - Rrup_avg**2
+        Rrup_var = integrand_width2[0] - Rrup_avg ** 2
     else:
         Rrup_avg = np.trapz(peps * integrand_width, dx=d_eps)
-        Rrup_var = np.trapz(peps * integrand_width2, dx=d_eps) - Rrup_avg**2
+        Rrup_var = np.trapz(peps * integrand_width2, dx=d_eps) - Rrup_avg ** 2
 
     return Rrup_var, Rrup_avg
 
@@ -747,33 +730,24 @@ def single_event_inner_loop(conf, Repi, theta=0, ntheta=73):
             for i in range(0, nx):  # x
                 xj = x[i] + Repi * np.cos(theta)
 
-                xltz = xj < 0
-                xgez_and_xlesw = (xj >= 0) & (xj <= SW)
-                xgtsw = xj > SW
-                c1x = xltz
-                c2x = xgez_and_xlesw
-                c3x = xgtsw
-                c4x = xltz
-                c5x = xgez_and_xlesw
-                c6x = xgtsw
-                c7x = xltz
-                c8x = xgez_and_xlesw
-                c9x = xgtsw
+                c147x = xj < 0
+                c258x = (xj >= 0) & (xj <= SW)
+                c369x = xj > SW
                 for j in range(0, ny):
                     yi = y[j] + Repi * np.sin(theta)
 
                     cca = yi > L
                     ccb = (yi >= 0) & (yi <= L)
                     ccc = yi < 0
-                    c1 = c1x & cca
-                    c2 = c2x & cca
-                    c3 = c3x & cca
-                    c4 = c4x & ccb
-                    c5 = c5x & ccb
-                    c6 = c6x & ccb
-                    c7 = c7x & ccc
-                    c8 = c8x & ccc
-                    c9 = c9x & ccc
+                    c1 = c147x & cca
+                    c2 = c258x & cca
+                    c3 = c369x & cca
+                    c4 = c147x & ccb
+                    c5 = c258x & ccb
+                    c6 = c369x & ccb
+                    c7 = c147x & ccc
+                    c8 = c258x & ccc
+                    c9 = c369x & ccc
                     xx = xj[c1]
                     yy = yi[c1] - L
                     Rjb[c1] = np.sqrt(xx * xx + yy * yy)
@@ -799,11 +773,11 @@ def single_event_inner_loop(conf, Repi, theta=0, ntheta=73):
                     # Compute Rrup prime, then Rrup
                     # using Kaklamanos eqns
                     if dip[k] == np.pi / 2:
-                        Rrup = np.sqrt(Rjb**2 + Ztor**2)
+                        Rrup = np.sqrt(Rjb ** 2 + Ztor ** 2)
                     else:
                         tmp = Ztor * np.tan(dip[k])
                         r1 = Rx < tmp
-                        Rrupp[r1] = np.sqrt(Rx[r1] ** 2 + Ztor**2)
+                        Rrupp[r1] = np.sqrt(Rx[r1] ** 2 + Ztor ** 2)
                         r2 = (tmp <= Rx) & (Rx <= (tmp + W / np.cos(dip[k])))
                         Rrupp[r2] = Rx[r2] * np.sin(dip[k]) + Ztor * np.cos(dip[k])
                         r3 = Rx > (tmp + W / np.cos(dip[k]))
@@ -811,8 +785,8 @@ def single_event_inner_loop(conf, Repi, theta=0, ntheta=73):
                             (Rx[r3] - W * np.cos(dip[k])) ** 2
                             + (Ztor + W * np.sin(dip[k])) ** 2
                         )
+                        Rrup = np.sqrt(Rrupp ** 2 + Ry ** 2)
 
-                    Rrup = np.sqrt(Rrupp**2 + Ry**2)
                     Rrup2 = Rrup * Rrup
                     Rjb2 = Rjb * Rjb
                     if conf["bytheta"] is False:
@@ -847,13 +821,13 @@ def single_event_inner_loop(conf, Repi, theta=0, ntheta=73):
             RjbIntegrand_a2[m] = dipnorm * np.trapz(RjbIntegrand_d2, dx=ddip)
     if conf["neps"] == 1:
         Rrup_avg = RrupIntegrand_a[0]
-        Rrup_var = RrupIntegrand_a2[0] - Rrup_avg**2
+        Rrup_var = RrupIntegrand_a2[0] - Rrup_avg ** 2
         Rjb_avg = RjbIntegrand_a[0]
-        Rjb_var = RjbIntegrand_a2[0] - Rjb_avg**2
+        Rjb_var = RjbIntegrand_a2[0] - Rjb_avg ** 2
     else:
         Rrup_avg = np.trapz(peps * RrupIntegrand_a, dx=d_eps)
-        Rrup_var = np.trapz(peps * RrupIntegrand_a2, dx=d_eps) - Rrup_avg**2
+        Rrup_var = np.trapz(peps * RrupIntegrand_a2, dx=d_eps) - Rrup_avg ** 2
         Rjb_avg = np.trapz(peps * RjbIntegrand_a, dx=d_eps)
-        Rjb_var = np.trapz(peps * RjbIntegrand_a2, dx=d_eps) - Rjb_avg**2
+        Rjb_var = np.trapz(peps * RjbIntegrand_a2, dx=d_eps) - Rjb_avg ** 2
 
     return Rrup_var, Rrup_avg, Rjb_var, Rjb_avg
